@@ -3,6 +3,7 @@
 #include "dbaccess.h"
 #include "dbcache.h"
 #include "cfg.h"
+#include "ibw.h"
 
 int cacheadd(const char *iface, int sync)
 {
@@ -272,7 +273,7 @@ uint32_t dbcheck(uint32_t dbhash, int *forcesave)
 	int offset, found;
 
 	/* get list of currently visible interfaces */
-	if (getiflist(&ifacelist)==0) {
+	if (getiflist(&ifacelist, 0)==0) {
 		free(ifacelist);
 		return 0;
 	}
