@@ -11,7 +11,7 @@ void showweeks(void);
 void showhours(void);
 void showoneline(void);
 void exportdb(void);
-void showbar(uint64_t rx, int rxk, uint64_t tx, int txk, uint64_t max, int len);
+int showbar(uint64_t rx, int rxk, uint64_t tx, int txk, uint64_t max, int len);
 void indent(int i);
 
 #endif
