@@ -1,5 +1,5 @@
 /*
-vnStat daemon - Copyright (c) 2008-2014 Teemu Toivola <tst@iki.fi>
+vnStat daemon - Copyright (c) 2008-2015 Teemu Toivola <tst@iki.fi>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@ vnStat daemon - Copyright (c) 2008-2014 Teemu Toivola <tst@iki.fi>
 #include "common.h"
 #include "dbcache.h"
 #include "cfg.h"
+#include "ibw.h"
 #include "daemon.h"
 #include "vnstatd.h"
 
@@ -52,6 +53,9 @@ int main(int argc, char *argv[])
 	if (!loadcfg(s.cfgfile)) {
 		return 1;
 	}
+	if (!ibwloadcfg(s.cfgfile)) {
+		return 1;
+	}
 
 	/* init dirname and other config settings */
 	strncpy_nt(s.dirname, cfg.dbdir, 512);
@@ -163,6 +167,7 @@ int main(int argc, char *argv[])
 			if (debug) {
 				debugtimestamp();
 				cacheshow();
+				ibwlist();
 			}
 
 			/* fill database list if cache is empty */
